@@ -44,6 +44,7 @@ use serde::{Deserialize, Serialize};
 const ENDPOINT: &str = "https://demo.docusign.net/restapi/v2.1/";
 
 /// Entrypoint for interacting with the DocuSign API.
+#[derive(Debug, Clone)]
 pub struct DocuSign {
     token: String,
     jwt_config: JWTConfig,
@@ -72,8 +73,7 @@ impl DocuSign {
                     integrator_key: integration_key.to_string(),
                     key_pair_id: key_pair_id.to_string(),
                     api_username: api_username.to_string(),
-                    // TODO: set this to false when we are live.
-                    is_demo: true,
+                    is_demo: false,
                 };
 
                 // This is super hacky and a work arouind since there is no way to
